@@ -1,11 +1,15 @@
-from classytags.utils import TemplateConstant, NULL, ResolvableList
 from classytags.exceptions import InvalidFlag
+from classytags.utils import TemplateConstant, NULL
+from classytags.values import StringValue, IntegerValue, ListValue
 from django.core.exceptions import ImproperlyConfigured
 
+
 class Argument(object):
     """
     A basic single value argument.
     """
+    value_class = StringValue
+    
     def __init__(self, name, default=None, required=True, resolve=True):
         self.name = name
         self.default = default
@@ -34,15 +38,25 @@ class Argument(object):
         if self.name in kwargs:
             return False
         else:
-            kwargs[self.name] = self.parse_token(parser, token)
+            value = self.parse_token(parser, token)
+            kwargs[self.name] = self.value_class(value)
             return True
+        
+
+class IntegerArgument(Argument):
+    """
+    Same as Argument but converts the value to integers.
+    """
+    value_class = IntegerValue
     
     
 class MultiValueArgument(Argument):
     """
     An argument which allows multiple values.
     """
-    sequence_class = ResolvableList
+    sequence_class = ListValue
+    value_class = StringValue
+    
     def __init__(self, name, default=NULL, required=True, max_values=None,
                  resolve=True):
         self.max_values = max_values
@@ -54,7 +68,7 @@ class MultiValueArgument(Argument):
         """
         Parse a token.
         """
-        value = self.parse_token(parser, token)
+        value = self.value_class(self.parse_token(parser, token))
         if self.name in kwargs:
             if self.max_values and len(kwargs[self.name]) == self.max_values:
                 return False
